//
//	Simple test GUI
//

#include "MyGui.h"
ClassImp(MyMainFrame);
ClassImp(CanvasBGFrame);


//______________________________________________________________________________
MyMainFrame::MyMainFrame(const TGWindow *p, UInt_t w, UInt_t h){
	// Create test main frame. A TGMainFrame is a top level window.
	std::cout.precision(3);
	fMain = new TGMainFrame(p, w, h);
	fMain->SetCleanup(kDeepCleanup);
	fMain->Connect("CloseWindow()", "MyMainFrame", this, "CloseWindow()");
	fMain->SetWindowName("Simple test GUI");

	fFrameCnv = new CanvasBGFrame(fMain, h, h, kChildFrame, TColor::Number2Pixel(1));
	fFrameCnv->SetName("CanvasFrame1");
	fMain->AddFrame(fFrameCnv, new TGLayoutHints(kLHintsNormal | kLHintsExpandX | kLHintsExpandY, 1,1,1,1));
	fFrameCnv->Connect("ProcessedEvent(Event_t*)","MyMainFrame",this,"ResizeCanvas(Event_t*)");
	fFrameCnv->Connect("UnZoom()","MyMainFrame",this,"UnZoomCurrentImage()");


	// Create the embedded canvas
	//fEmbCanvas = new TRootEmbeddedCanvas("Canvas1",fMain,1020,768,kChildFrame,TColor::Number2Pixel(1));
	fEmbCanvas = new TRootEmbeddedCanvas("Canvas1",fFrameCnv,1020,768,kChildFrame,TColor::Number2Pixel(1));
	fFrameCnv->AddFrame(fEmbCanvas, new TGLayoutHints(kLHintsCenterX | kLHintsCenterY, 0,0,0,0));
	fEmbCanvas->GetCanvas()->SetFillColor(1);
	fEmbCanvas->GetCanvas()->SetMargin(0,0,0,0);
	fEmbCanvas->GetCanvas()->Connect("ProcessedEvent(Int_t,Int_t,Int_t,TObject*)","MyMainFrame",this,"ExecEvent(Int_t,Int_t,Int_t,TObject*)");
	fEmbCanvas->GetCanvas()->Connect("Modified()","MyMainFrame",this,"CanvasModified()");

	// Map main frame
	fMain->MapSubwindows();
	fMain->Resize(fMain->GetDefaultSize());
	fMain->MapWindow();

	// Draw Image
	fImg = (TASImage*)TImage::Open("rose512_bw.jpg");
	fImg->Draw();
	xZoomOld = 0;
	yZoomOld = 0;
	wZoomOld = fImg->GetWidth();
	hZoomOld = fImg->GetHeight();
}
//______________________________________________________________________________
MyMainFrame::~MyMainFrame(){ fMain->Cleanup(); }

//______________________________________________________________________________
void MyMainFrame::CanvasModified(){
	if(WasZoomed()){
		ResizeCanvas();
		fFrameCnv->Layout();
	}
}
//______________________________________________________________________________
void MyMainFrame::CloseWindow(){ gApplication->Terminate(); }

//______________________________________________________________________________
void MyMainFrame::ExecEvent(Int_t event, Int_t px, Int_t py, TObject *selected){}

//______________________________________________________________________________
void MyMainFrame::ResizeCanvas(Event_t* event){
	Double_t rImage = (Double_t)wZoomOld / (Double_t)hZoomOld;
	if( (Double_t)fFrameCnv->GetHeight() * rImage < (Double_t)fFrameCnv->GetWidth() ){
		fEmbCanvas->SetHeight(fFrameCnv->GetHeight());
		fEmbCanvas->SetWidth(TMath::Nint((Double_t)fFrameCnv->GetHeight() * rImage));
	}
	else if( (Double_t)fFrameCnv->GetWidth() / rImage < (Double_t)fFrameCnv->GetHeight() ){
		fEmbCanvas->SetWidth(fFrameCnv->GetWidth());
		fEmbCanvas->SetHeight(TMath::Nint((Double_t)fFrameCnv->GetWidth() / rImage));
	}
}

//______________________________________________________________________________
Bool_t MyMainFrame::WasZoomed(){
	Bool_t zoomed = kFALSE;
	UInt_t xZoom, yZoom, wZoom, hZoom;
	fImg->GetZoomPosition(xZoom, yZoom, wZoom, hZoom);
	if(xZoom!= xZoomOld || yZoom!= yZoomOld || wZoom!= wZoomOld || hZoom!= hZoomOld)
		zoomed = kTRUE;
	xZoomOld = xZoom;
	yZoomOld = yZoom;
	wZoomOld = wZoom;
	hZoomOld = hZoom;
	return zoomed;
}

//______________________________________________________________________________
void MyMainFrame::UnZoomCurrentImage(){
	fImg->UnZoom();
	fEmbCanvas->GetCanvas()->Modified();
	fEmbCanvas->GetCanvas()->Update();
}

//______________________________________________________________________________
void MyGui(){
	// pop up the GUI
	new MyMainFrame(gClient->GetRoot(), 600, 600);
}

int main(int argc, char **argv) {
	TApplication theApp("App",&argc,argv);
	MyGui();
	theApp.Run();
	return 0;
}
