#include <iostream>

#include <TApplication.h>
#include <TASImage.h>
#include <TCanvas.h>
#include <TClass.h>
#include <TContextMenu.h>
#include <TColor.h>
#include <TGFrame.h>
#include <TMath.h>
#include <TRootEmbeddedCanvas.h>
#include <TROOT.h>
#include <RQ_OBJECT.h>

class CanvasBGFrame : public TGCompositeFrame
{
public:
	TContextMenu* fContextMenu;

	CanvasBGFrame(const TGWindow *p = 0, UInt_t w = 1, UInt_t h = 1, UInt_t options = 0, Pixel_t back = GetDefaultFrameBackground()) : TGCompositeFrame(p,w,h,options,back){
		AddInput(kButtonPressMask | kButtonReleaseMask);
		fContextMenu = new TContextMenu("CanvasBGFrame");
		this->Connect("ProcessedEvent(Event_t*)","CanvasBGFrame", this, "CBGFEvent(Event_t*)");
	};
	~CanvasBGFrame(){};

	virtual void CBGFEvent(Event_t *ev){
		// only popup context menu if user clicked with the right button
		if (ev->fType == kButtonRelease && ev->fCode == kButton3) {
			Int_t px = 0, py = 0;
			Window_t wtarget;
			// translate coordinates from the event window (the list box container) to the root (desktop) window
			gVirtualX->TranslateCoordinates(ev->fWindow, gClient->GetDefaultRoot()->GetId(), ev->fX, ev->fY, px, py, wtarget);
			// popup the context menu, automatically using the TGListBox methods having // *MENU* as comment
			fContextMenu->Popup(px, py, this);
		}
	};
	virtual void UnZoom(){ Emit("UnZoom()"); }; // *MENU* *SIGNAL*

	ClassDef(CanvasBGFrame, 0);
};


class MyMainFrame : public TGMainFrame
{
  RQ_OBJECT("MyMainFrame")
    
private:
  TGMainFrame         	*fMain;
  CanvasBGFrame			*fFrameCnv;
  TRootEmbeddedCanvas 	*fEmbCanvas;
  TASImage	      		*fImg;
  UInt_t				xZoomOld, yZoomOld, wZoomOld, hZoomOld;

public:
  MyMainFrame(const TGWindow *p, UInt_t w, UInt_t h);
  virtual ~MyMainFrame();
  
  virtual void CanvasModified();
  virtual void CloseWindow();
  virtual void ExecEvent(Int_t event, Int_t px, Int_t py, TObject *selected);
  virtual void ResizeCanvas(Event_t* event = 0);
  virtual Bool_t WasZoomed();
  virtual void UnZoomCurrentImage();
  
  ClassDef(MyMainFrame, 1)
};
